==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--ignored case--
--file: locale_it_BKChem.po--
Esplodi gli oggetti testo in singole lettere
Seleziona Singolo Oggetto</translatorcomment>
        <translation type="obsolete">Singolo</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Due: verticale</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Due: orizzontale</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tre: destra</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tre: sinistra</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tre: sopra</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tre: al di sotto</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tre: verticale</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tre: orizzontale</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quattro: equal</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quattro: giusto</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quattro: sinistra</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Spaziatura della griglia &lt; Meta spaziatura della griglia</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Quattro: equal</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Quattro: sinistra</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Quattro: giusto</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Singolo</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Tre: al di sotto</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Tre: orizzontale</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Tre: verticale</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Due: orizzontale</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Due: verticale</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translation>Griglia</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Sull&apos;entità</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translatorcomment>--exact match--
--file: SnapPerpendicular_it.ts--
&amp;Perpendicolare
Perpendicolare
Seleziona il piano perpendicolare alla vista corrente</translatorcomment>
        <translation>Perpendicolare</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersezione</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Riferimento</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Spaziatura della griglia &lt; Meta spaziatura della griglia</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Spaziatura della griglia &lt; Meta spaziatura della griglia</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--ignored case--
--file: locale_it_BKChem.po--
Esplodi gli oggetti testo in singole lettere
Seleziona Singolo Oggetto</translatorcomment>
        <translation type="obsolete">Singolo</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Due: verticale</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Due: orizzontale</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tre: destra</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tre: sinistra</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tre: sopra</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tre: al di sotto</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tre: verticale</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tre: orizzontale</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quattro: equal</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quattro: giusto</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quattro: sinistra</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Spaziatura della griglia &lt; Meta spaziatura della griglia</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Quattro: equal</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Quattro: sinistra</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Quattro: giusto</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Singolo</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Tre: al di sotto</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Tre: orizzontale</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Tre: verticale</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Due: orizzontale</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Due: verticale</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation>I dati inseriti non sono supportati</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation>File importazione: </translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation>Importazione URL: </translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="vanished">Griglia</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="vanished">Fine</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translation type="vanished">Sull&apos;entità</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translatorcomment>--exact match--
--file: SnapPerpendicular_it.ts--
&amp;Perpendicolare
Perpendicolare
Seleziona il piano perpendicolare alla vista corrente</translatorcomment>
        <translation type="vanished">Perpendicolare</translation>
    </message>
    <message>
        <source>Tangential</source>
        <translation type="vanished">Tangenziale</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Medio</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translation type="vanished">Intersezione</translation>
    </message>
    <message>
        <source>Reference</source>
        <translation type="vanished">Riferimento</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Spaziatura della griglia &lt; Meta spaziatura della griglia</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Spaziatura della griglia &lt; Meta spaziatura della griglia</translation>
    </message>
</context>
</TS>
